@@ -1,24 +1,22 @@
-
-
-##' Simulation of Buffon's Needle
+##' Simulation of Buffon's Needle.
 ##' This function provides a simulation for the problem of Buffon's Needle,
 ##' which is one of the oldest problems in the field of geometrical
 ##' probability.
-##' 
+##'
 ##' This is quite an old problem in probability. For mathematical background,
 ##' please refer to \url{http://en.wikipedia.org/wiki/Buffon's_needle} or
 ##' \url{http://www.mste.uiuc.edu/reese/buffon/buffon.html}.
-##' 
+##'
 ##' `Needles' are denoted by segments on the 2D plane, and dropped randomly to
 ##' check whether they cross the parallel lines. Through many times of
 ##' `dropping' needles, the approximate value of \eqn{\pi} can be calculated
 ##' out.
-##' 
+##'
 ##' There are three graphs made in each step: the top-left one is a simulation
 ##' of the scenario, the top-right one is to help us understand the connection
 ##' between dropping needles and the mathematical method to estimate \eqn{\pi},
 ##' and the bottom one is the result for each dropping.
-##' 
+##'
 ##' @param l numerical. length of the needle; shorter than \code{d}.
 ##' @param d numerical. distances between lines; it should be longer than
 ##'   \code{l}.
@@ -46,22 +44,22 @@
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @references Ramaley, J. F. (Oct 1969). Buffon's Noodle Problem. \emph{The
 ##'   American Mathematical Monthly} \bold{76} (8): 916-918.
-##' 
+##'
 ##' \url{http://animation.yihui.name/prob:buffon_s_needle}
 ##' @keywords dplot hplot dynamic math
 ##' @examples
-##' 
-##' # it takes several seconds if 'redraw = TRUE' 
+##'
+##' # it takes several seconds if 'redraw = TRUE'
 ##' oopt = ani.options(nmax = 500, interval = 0)
 ##' opar = par(mar = c(3, 2.5, 0.5, 0.2), pch = 20, mgp = c(1.5, 0.5, 0))
 ##' buffon.needle()
-##' 
-##' # this will be faster 
+##'
+##' # this will be faster
 ##' buffon.needle(redraw = FALSE)
-##' 
+##'
 ##' par(opar)
-##' 
-##' \dontrun{ 
+##'
+##' \dontrun{
 ##' # create HTML animation page
 ##' ani.options(nmax = 100, interval = 0.1, ani.height = 500, ani.width = 600,
 ##'     title = "Simulation of Buffon's Needle",
@@ -73,12 +71,12 @@
 ##' ani.start()
 ##' par(mar = c(3, 2.5, 1, 0.2), pch = 20, mgp = c(1.5, 0.5, 0))
 ##' buffon.needle(type = "S")
-##' ani.stop() 
+##' ani.stop()
 ##' }
-##' 
+##'
 ##' ani.options(oopt)
-##' 
-`buffon.needle` <- function(l = 0.8, d = 1, redraw = TRUE,
+##'
+buffon.needle = function(l = 0.8, d = 1, redraw = TRUE,
     mat = matrix(c(1, 3, 2, 3), 2), heights = c(3, 2), col = c("lightgray",
         "red", "gray", "red", "blue", "black", "red"), expand = 0.4,
     type = "l", ...) {
