@@ -1,14 +1,12 @@
-
-
-##' Demonstrate the Least Squares
+##' Demonstrate the least squares method.
 ##' This is a simple demonstration of the meaning of least squares in
 ##' univariate linear regression.
-##' 
+##'
 ##' With either the intercept or the slope changing, the lines will be moving
 ##' in the graph and corresponding residuals will be plotted. We can finally
 ##' see the best estimate of the intercept and the slope from the residual
 ##' plot.
-##' 
+##'
 ##' @param x a numeric vector: the independent variable
 ##' @param y a numeric vector: the dependent variable
 ##' @param n the sample size: when x and y are missing, we use simulated values
@@ -32,30 +30,30 @@
 ##' @param \dots other parameters passed to \code{\link[graphics]{plot}} to
 ##'   define the appearance of the scatterplot
 ##' @return The value returned depends on the animation type.
-##' 
+##'
 ##' If it is a slope animation, the value will be a list containing \item{lmfit
 ##'   }{ the estimates of the intercept and slope with \code{\link[stats]{lm}}
 ##'   } \item{anifit }{ the estimate of the slope in the animation } If it is
 ##'   an intercept animation, the second component of the above list will be
 ##'   the estimate of the intercept.
-##' 
+##'
 ##' Note the estimate will not be precise generally.
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @seealso \code{\link[stats]{lm}}
 ##' @references \url{http://animation.yihui.name/lm:least_squares}
 ##' @keywords dynamic models
 ##' @examples
-##' 
+##'
 ##' opar = par(mar = c(5, 4, 0.5, 0.1))
 ##' oopt = ani.options(interval = 0.3, nmax = 50)
 ##' # default animation: with slope changing
 ##' least.squares()
 ##' # intercept changing
 ##' least.squares(ani.type = "i")
-##' 
+##'
 ##' par(opar)
-##' 
-##' \dontrun{ 
+##'
+##' \dontrun{
 ##' # save the animation in HTML pages
 ##' ani.options(ani.height = 450, ani.width = 600,
 ##'     title = "Demonstration of Least Squares",
@@ -66,30 +64,29 @@
 ##' least.squares()
 ##' ani.stop()
 ##' }
-##' 
+##'
 ##' ani.options(oopt)
-##' 
-`least.squares` <-
-function(x, y, n = 15, ani.type = c("slope", 
-    "intercept"), a, b, a.range, b.range, ab.col = c("gray", 
-    "black"), est.pch = 19, v.col = "red", v.lty = 2, rss.pch = 19, 
+##'
+least.squares = function(x, y, n = 15, ani.type = c("slope",
+    "intercept"), a, b, a.range, b.range, ab.col = c("gray",
+    "black"), est.pch = 19, v.col = "red", v.lty = 2, rss.pch = 19,
     rss.type = "o", mfrow = c(1, 2), ...) {
     interval = ani.options("interval")
     nmax = ani.options("nmax")
-    if (missing(x)) 
+    if (missing(x))
         x = 1:n
-    if (missing(y)) 
+    if (missing(y))
         y = x + rnorm(n)
     ani.type = match.arg(ani.type)
     fit = coef(lm(y ~ x))
-    if (missing(a)) 
+    if (missing(a))
         a = fit[1]
-    if (missing(b)) 
+    if (missing(b))
         b = fit[2]
     rss = rep(NA, nmax)
     par(mfrow = mfrow)
     if (ani.type == "slope") {
-        if (missing(b.range)) 
+        if (missing(b.range))
             bseq = tan(seq(pi/10, 3.5 * pi/10, length = nmax))
         else bseq = seq(b.range[1], b.range[2], length = nmax)
         for (i in 1:nmax) {
@@ -99,15 +96,15 @@ function(x, y, n = 15, ani.type = c("slope",
             points(x, bseq[i] * x + a, pch = est.pch)
             segments(x, bseq[i] * x + a, x, y, col = v.col, lty = v.lty)
             rss[i] = sum((y - bseq[i] * x - a)^2)
-            plot(1:nmax, rss, xlab = paste("Slope =", round(bseq[i], 
-                3)), ylab = "Residual Sum of Squares", pch = rss.pch, 
+            plot(1:nmax, rss, xlab = paste("Slope =", round(bseq[i],
+                3)), ylab = "Residual Sum of Squares", pch = rss.pch,
                 type = rss.type)
             Sys.sleep(interval)
         }
         return(invisible(list(lmfit = fit, anifit = c(x = bseq[which.min(rss)]))))
     }
     else if (ani.type == "intercept") {
-        if (missing(a.range)) 
+        if (missing(a.range))
             aseq = seq(-5, 5, length = nmax)
         else aseq = seq(a.range[1], a.range[2], length = nmax)
         for (i in 1:nmax) {
@@ -117,8 +114,8 @@ function(x, y, n = 15, ani.type = c("slope",
             points(x, b * x + aseq[i], pch = est.pch)
             segments(x, b * x + aseq[i], x, y, col = v.col, lty = v.lty)
             rss[i] = sum((y - b * x - aseq[i])^2)
-            plot(1:nmax, rss, xlab = paste("Intercept =", round(aseq[i], 
-                3)), ylab = "Residual Sum of Squares", pch = rss.pch, 
+            plot(1:nmax, rss, xlab = paste("Intercept =", round(aseq[i],
+                3)), ylab = "Residual Sum of Squares", pch = rss.pch,
                 type = rss.type)
             Sys.sleep(interval)
         }
