@@ -1,24 +1,22 @@
-
-
-##' Demonstration of the Newton-Raphson Method for Root-finding
+##' Demonstration of the Newton-Raphson method for root-finding.
 ##' This function provides an illustration of the iterations in Newton's
 ##' method.
-##' 
+##'
 ##' Newton's method (also known as the Newton-Raphson method or the
 ##' Newton-Fourier method) is an efficient algorithm for finding approximations
 ##' to the zeros (or roots) of a real-valued function f(x).
-##' 
+##'
 ##' The iteration goes on in this way:
-##' 
+##'
 ##' \deqn{x_{k + 1} = x_{k} - \frac{FUN(x_{k})}{FUN'(x_{k})}}{x[k + 1] = x[k] -
 ##' FUN(x[k]) / FUN'(x[k])}
-##' 
+##'
 ##' From the starting value \eqn{x_0}, vertical lines and points are plotted to
 ##' show the location of the sequence of iteration values \eqn{x_1, x_2,
 ##' \ldots}{x1, x2, \dots}; tangent lines are drawn to illustrate the
 ##' relationship between successive iterations; the iteration values are in the
 ##' right margin of the plot.
-##' 
+##'
 ##' @param FUN the function in the equation to solve (univariate), which has to
 ##'   be defined without braces like the default one (otherwise the derivative
 ##'   cannot be computed)
@@ -42,41 +40,41 @@
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @seealso \code{\link[stats]{optim}}
 ##' @references \url{http://en.wikipedia.org/wiki/Newton's_method}
-##' 
+##'
 ##' \url{http://animation.yihui.name/compstat:newton_s_method}
 ##' @keywords optimize dynamic dplot
 ##' @examples
-##' 
-##' 
+##'
+##'
 ##' oopt = ani.options(interval = 1, nmax = 50)
 ##' op = par(pch = 20)
-##' 
-##' # default example 
-##' xx = newton.method() 
+##'
+##' # default example
+##' xx = newton.method()
 ##' xx$root  # solution
-##' 
+##'
 ##' # take a long long journey
 ##' ani.options(nmax = 50)
 ##' newton.method(function(x) 5 * x^3 - 7 * x^2 - 40 *
 ##'     x + 100, 7.15, c(-6.2, 7.1))
-##' 
-##' # another function 
+##'
+##' # another function
 ##' ani.options(interval = 0.5, nmax = 50)
-##' xx = newton.method(function(x) exp(-x) * x, rg = c(0, 
-##'     10), init = 2) 
+##' xx = newton.method(function(x) exp(-x) * x, rg = c(0,
+##'     10), init = 2)
 ##' # not converge!
 ##' ani.options(interval = 0.5, nmax = 50)
-##' xx = newton.method(function(x) atan(x), rg = c(-5, 
-##'     5), init = 1.5) 
-##' xx$root   # Inf 
-##' 
+##' xx = newton.method(function(x) atan(x), rg = c(-5,
+##'     5), init = 1.5)
+##' xx$root   # Inf
+##'
 ##' \dontrun{
 ##' # interaction: use your mouse to select the starting point
 ##' ani.options(interval = 0.5, nmax = 50)
-##' xx = newton.method(function(x) atan(x), rg = c(-2, 
-##'     2), interact = TRUE) 
-##' 
-##' # HTML animation pages 
+##' xx = newton.method(function(x) atan(x), rg = c(-2,
+##'     2), interact = TRUE)
+##'
+##' # HTML animation pages
 ##' ani.options(ani.height = 500, ani.width = 600, nmax = 100,
 ##'     interval = 1, title = "Demonstration of the Newton-Raphson Method",
 ##'     description = "Go along with the tangent lines and iterate.")
@@ -86,11 +84,11 @@
 ##'     x + 100, 7.15, c(-6.2, 7.1), main = "")
 ##' ani.stop()
 ##' }
-##' 
-##' par(op) 
+##'
+##' par(op)
 ##' ani.options(oopt)
-##' 
-`newton.method` <- function(FUN = function(x) x^2 -
+##'
+newton.method = function(FUN = function(x) x^2 -
     4, init = 10, rg = c(-1, 10), tol = 0.001, interact = FALSE,
     col.lp = c("blue", "red", "red"), main, xlab, ylab, ...) {
     if (interact) {
