@@ -1,18 +1,16 @@
-
-
-##' Demonstration of the Quincunx (Bean Machine/Galton Box)
+##' Demonstration of the Quincunx (Bean Machine/Galton Box).
 ##' This function simulates the quincunx with ``balls'' (beans) falling through
 ##' several layers (denoted by triangles) and the distribution of the final
 ##' locations at which the balls hit is denoted by a histogram.
-##' 
+##'
 ##' The bean machine, also known as the quincunx or Galton box, is a device
 ##' invented by Sir Francis Galton to demonstrate the law of error and the
 ##' normal distribution.
-##' 
+##'
 ##' When a ball falls through a layer, it can either go to the right or left
 ##' side with the probability 0.5. At last the location of all the balls will
 ##' show us the bell-shaped distribution.
-##' 
+##'
 ##' @param balls number of balls
 ##' @param layers number of layers
 ##' @param pch.layers point character of layers; triangles (\code{pch = 2}) are
@@ -30,30 +28,29 @@
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @seealso \code{\link[stats:Binomial]{rbinom}}
 ##' @references \url{http://en.wikipedia.org/wiki/Bean_machine}
-##' 
+##'
 ##' \url{http://animation.yihui.name/prob:bean_machine}
 ##' @keywords dynamic distribution
 ##' @examples
-##' 
+##'
 ##' set.seed(123)
 ##' ani.options(nmax = 200 + 15 -2, interval = 0.03)
 ##' freq = quincunx(balls = 200, col.balls = rainbow(200))
 ##' # frequency table
 ##' barplot(freq, space = 0)
-##' 
+##'
 ##' \dontrun{
-##' ani.options(ani.height = 500, ani.width = 600, 
-##'     interval = 0.03, nmax = 213, title = "Demonstration of the Galton Box", 
+##' ani.options(ani.height = 500, ani.width = 600,
+##'     interval = 0.03, nmax = 213, title = "Demonstration of the Galton Box",
 ##'     description = "Balls falling through pins will show you the Normal
 ##'     distribution.")
 ##' ani.start()
 ##' quincunx()
 ##' ani.stop()
 ##' }
-##' 
-`quincunx` <-
-function(balls = 200, layers = 15, pch.layers = 2, 
-    pch.balls = 19, col.balls = sample(colors(), balls, TRUE), 
+##'
+quincunx = function(balls = 200, layers = 15, pch.layers = 2,
+    pch.balls = 19, col.balls = sample(colors(), balls, TRUE),
     cex.balls = 2) {
     op = par(mar = c(1, 0.1, 0.1, 0.1), mfrow = c(2, 1))
     if (ani.options("nmax") != (balls + layers - 2))
@@ -62,7 +59,7 @@ function(balls = 200, layers = 15, pch.layers = 2,
     interval = ani.options("interval")
     layerx = layery = NULL
     for (i in 1:layers) {
-        layerx = c(layerx, seq(0.5 * (i + 1), layers - 0.5 * 
+        layerx = c(layerx, seq(0.5 * (i + 1), layers - 0.5 *
             (i - 1), 1))
         layery = c(layery, rep(i, layers - i + 1))
     }
@@ -74,7 +71,7 @@ function(balls = 200, layers = 15, pch.layers = 2,
         if (layers > 2) {
             tmp = rbinom(layers - 2, 1, 0.5) * 2 - 1
             directx[i, i + 1:(layers - 2)] = tmp
-            ballx[i, i + 1:(layers - 2)] = cumsum(tmp) * 0.5 + 
+            ballx[i, i + 1:(layers - 2)] = cumsum(tmp) * 0.5 +
                 (1 + layers)/2
         }
         bally[i, (i - 1) + 1:(layers - 1)] = (layers - 1):1
@@ -85,13 +82,13 @@ function(balls = 200, layers = 15, pch.layers = 2,
     for (i in 1:ani.options("nmax")) {
         plot(1:layers, type = "n", ann = FALSE, axes = FALSE)
         points(layerx, layery, pch = pch.layers)
-        points(ballx[, i], bally[, i], pch = pch.balls, col = col.balls, 
+        points(ballx[, i], bally[, i], pch = pch.balls, col = col.balls,
             cex = cex.balls)
         par(bty = "u")
-        if (i < layers - 1) 
+        if (i < layers - 1)
             plot.new()
-        else hist(finalx[1:(i - layers + 2)], breaks = 1:layers, 
-            xlim = rgx, ylim = rgy, main = "", xlab = "", ylab = "", 
+        else hist(finalx[1:(i - layers + 2)], breaks = 1:layers,
+            xlim = rgx, ylim = rgy, main = "", xlab = "", ylab = "",
             ann = FALSE, axes = FALSE)
         Sys.sleep(interval)
     }
